@@ -83,7 +83,7 @@ def import_torch_dataset(name, dataset, classes, state, model):
     :type dataset: torch.utils.data.DataLoader
     :param classes: an ordered list of strings representing class names
     :type classes: list
-    :param state: a 3D array of floats [layers,neurons,activations]. Length of activations must be the same as the number of images.
+    :param state: a 3D array of floats [layers,activations,neurons]. Length of activations must be the same as the number of images.
     :type state: Union[list,np.ndarray]
     :param model: the model structure
     :type model: deephys.deephys.Model
@@ -123,7 +123,7 @@ def import_test_data(name, classes, state, model, pixel_data, ground_truths):
     :type name: str
     :param classes: an ordered list of strings representing class names
     :type classes: list
-    :param state: a 3D array of floats [layers,neurons,activations]. Length of activations must be the same as the number of images.
+    :param state: a 3D array of floats [layers,activations,neurons]. Length of activations must be the same as the number of images.
     :type state: Union[list,np.ndarray]
     :param model: the model structure
     :type model: deephys.deephys.Model
@@ -157,7 +157,7 @@ def import_test_data(name, classes, state, model, pixel_data, ground_truths):
         chan_to_bytes = lambda chan: [bytes(row) for row in chan]
         im_to_bytes = lambda im: list(map(chan_to_bytes, im))
         im_as_list = image.numpy().astype(np.uint8).tolist()
-        im_activations = list(map(lambda l: l[:, i], state))
+        im_activations = list(map(lambda l: l[i, :], state))
         imageList.append(
             ImageFile(
                 imageID=i,
